#coding=utf8

# This file is part of CloudControl.
#
# CloudControl is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# CloudControl is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with CloudControl.  If not, see <http://www.gnu.org/licenses/>.

'''
CloudControl tag releated commands
'''

from cccli.exception import *
from sjrpc.core.exceptions import *
from cccli.printer import Printer, color
from cccli.command import TqlCommand

from optparse import OptionParser

class Command_tags(TqlCommand):
    '''List only static tags'''

    def __init__(self, cli, argv0):
        TqlCommand.__init__(self, cli, argv0)
        self.set_usage("%prog [options] [tql]")
        self.remove_option("--quiet")
        self.remove_option("--direct")
        self.tql_filter += "&a"

    def __call__(self, argv):
        # Parse argline
        self.parse_args(argv)
        # append current login if nothing asked
        if len(self.args) == 0:
            tql = "a=%s"%self.cli.settings["login"]
        else:
            tql = "".join(self.args)
        # ask server
        objs = self.rpccall("tags", tql, _direct=True, _status=False)
        # display answer
        self.print_objects(objs)

    def remote_functions(self):
        return set(("tags",))


class Command_addtag(TqlCommand):
    '''Add/Modify a static tag on an account'''

    def __init__(self, cli, argv0):
        TqlCommand.__init__(self, cli, argv0)
        self.tql_filter += "&a"
        self.set_usage("%prog [options] <tql> <tag> <value>")

    def __call__(self, argv):
        # argv check
        self.parse_args(argv)
        if len(self.args) != 3:
            raise cmdBadArgument()
        # rpc call
        self.rpccall("addtag", self.args[0], self.args[1], self.args[2])

    def remote_functions(self):
        return set(("addtag",))


class Command_deltag(TqlCommand):
    '''Delete a static tag from an account'''

    def __init__(self, cli, argv0):
        TqlCommand.__init__(self, cli, argv0)
        self.tql_filter += "&a"
        self.set_usage("%prog [options] <tql> <tag>")

    def __call__(self, argv):
        # argv check
        self.parse_args(argv)
        if len(self.args) != 2:
            raise cmdBadArgument()
        # rpc call
        self.rpccall("deltag", self.args[0], self.args[1])

    def remote_functions(self):
        return set(("deltag",))
